@@ -1,24 +1,10 @@
 /*
  * BluezQt - Asynchronous BlueZ wrapper library
  *
- * Copyright (C) 2014 Alejandro Fiestas Olivares <afiestas@kde.org>
- *               2014-2015 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2014 Alejandro Fiestas Olivares <afiestas@kde.org>
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #ifndef BLUEZQT_JOB_H
@@ -30,10 +16,11 @@
 
 namespace BluezQt
 {
-
 class JobPrivate;
 
 /**
+ * @class BluezQt::Job job.h <BluezQt/Job>
+ *
  * This class represents an asynchronous job performed by BluezQt,
  * it is usually not used directly but instead it is inherit by some
  * other class.
@@ -57,7 +44,6 @@ class JobPrivate;
 class BLUEZQT_EXPORT Job : public QObject
 {
     Q_OBJECT
-    Q_ENUMS(Error)
     Q_PROPERTY(int error READ error)
     Q_PROPERTY(QString errorText READ errorText)
     Q_PROPERTY(bool running READ isRunning)
@@ -69,7 +55,7 @@ public:
      *
      * @param parent
      */
-    explicit Job(QObject *parent = Q_NULLPTR);
+    explicit Job(QObject *parent = nullptr);
 
     /**
      * Destroys a Job object.
@@ -87,6 +73,7 @@ public:
         /** Subclasses should define error codes starting at this value */
         UserDefinedError = 100
     };
+    Q_ENUM(Error)
 
     /**
      * Executes the job synchronously.
@@ -100,7 +87,7 @@ public:
      * called, which usually wreaks havoc.
      *
      * Note that the event loop started by this method does not process user input events, which means
-     * your user interface will effectivly be blocked. Other events like paint or network events are
+     * your user interface will effectively be blocked. Other events like paint or network events are
      * still being processed. The advantage of not processing user input events is that the chance of
      * accidental reentrancy is greatly reduced. Still you should avoid calling this function.
      *
@@ -240,4 +227,4 @@ private:
 
 } // namespace BluezQt
 
-#endif //BLUEZQT_JOB_H
+#endif // BLUEZQT_JOB_H
