@@ -1,23 +1,9 @@
 /*
  * BluezQt - Asynchronous BlueZ wrapper library
  *
- * Copyright (C) 2015 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2015 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #ifndef BLUEZQT_MEDIAPLAYER_H
@@ -25,13 +11,12 @@
 
 #include <QObject>
 
-#include "types.h"
-#include "mediaplayertrack.h"
 #include "bluezqt_export.h"
+#include "mediaplayertrack.h"
+#include "types.h"
 
 namespace BluezQt
 {
-
 class PendingCall;
 
 /**
@@ -58,7 +43,7 @@ public:
         /** Equalizer on. */
         EqualizerOn,
         /** Equalizer off. */
-        EqualizerOff
+        EqualizerOff,
     };
     Q_ENUM(Equalizer)
 
@@ -71,7 +56,7 @@ public:
         /** Repeat all tracks. */
         RepeatAllTracks,
         /** Repeat group. */
-        RepeatGroup
+        RepeatGroup,
     };
     Q_ENUM(Repeat)
 
@@ -82,7 +67,7 @@ public:
         /** Shuffle all tracks. */
         ShuffleAllTracks,
         /** Shuffle group. */
-        ShuffleGroup
+        ShuffleGroup,
     };
     Q_ENUM(Shuffle)
 
@@ -99,7 +84,7 @@ public:
         /** Player is reverse seeking. */
         ReverseSeek,
         /** Error */
-        Error
+        Error,
     };
     Q_ENUM(Status)
 
